Module keycode

Module keycode 

Logical keycodes (layout-aware) — SDL’s SDLK_* constants.

For printable keys the keycode is the Unicode code point of the base character produced by the key in the current layout (e.g. SDLK_A = 'a'). Non-printable keys are encoded as scancode | SCANCODE_MASK.

Structs

Keycode
A logical keycode — either a Unicode code point or scancode | SCANCODE_MASK.

Constants

SCANCODE_MASK
Bit OR-ed into non-printable keycodes to distinguish them from Unicode code points. Value is identical in SDL2 and SDL3.